<?php

App::uses('OrderBuilderInterface', 'EvCheckout.Lib');
App::uses('OrderBuilder', 'EvCheckout.Lib');
App::uses('AddressBookLib', 'EvAddressBook.Lib');
App::uses('BasketLib', 'EvBasket.Lib');

class BasketBuilder extends OrderBuilder implements OrderBuilderInterface {

	/**
	 * build an order from a basket
	 *
	 * @param 	int 	$transactionId 		The successful transaction ID just completed
	 * @return  int 	$orderId 			The id number of the order we just created
	 */
	public function build($transactionId) {
		if (! CakePlugin::loaded('EvBasket')) {
			$this->_controller->Flash->fail('EvBasket is not loaded. Cannot process basket');
			return false;
		}

		if (! CakePlugin::loaded('EvAddressBook')) {
			$this->_controller->Flash->fail('EvAddressBook is not loaded. Cannot retrieve addresses');
			return false;
		}

		// load the mbasket manager so we can get the basket
		if (empty($this->_controller->BasketManager)) {
			$this->_controller->BasketManager = $this->_controller->loadComponent('EvBasket.Basket');
		}

		// get the addresses
		$TransactionModel = EvClassRegistry::init('EvTransactions.Transaction');
		$transaction = $TransactionModel->readForView($transactionId);

		$addresses = array();
		if (! empty($transaction['TransactionData']['addresses'])) {
			$addresses = json_decode($transaction['TransactionData']['addresses'], true);

			// format the addresses
			foreach ($addresses as $key => $address) {
				$addresses[$key] = AddressBookLib::display($address);
			}
		}

		$orderId = $this->_controller->OrderManager->createFromBasket(
			$this->_controller->BasketManager->getBasket(),
			$this->_controller->Auth->user('User'),
			$addresses
		);

		$this->_controller->OrderManager->markAsPaid($orderId);

		// clear the basket
		BasketLib::deleteBasket($transaction['Transaction']['model_id']);

		// update the transaction to reference the order
		$this->_controller->OrderManager->assignToTransaction(
			$orderId,
			$transactionId
		);

		return $orderId;
	}

}
